gnome-games r7190 - trunk/aisleriot



Author: chpe
Date: Sun Jan 13 22:08:14 2008
New Revision: 7190
URL: http://svn.gnome.org/viewvc/gnome-games?rev=7190&view=rev

Log:
Hide the focus when starting a drag.


Modified:
   trunk/aisleriot/board.c

Modified: trunk/aisleriot/board.c
==============================================================================
--- trunk/aisleriot/board.c	(original)
+++ trunk/aisleriot/board.c	Sun Jan 13 22:08:14 2008
@@ -1056,8 +1056,9 @@
   aisleriot_game_record_move (priv->game, hslot->id,
                               cards->data, cards->len);
 
   /* Unset the selection. It'll be re-set if the drag is aborted */
   set_selection (board, NULL, -1, FALSE);
+  set_focus (board, NULL, -1, FALSE);
 
   delta = hslot->exposed - num_moving_cards;
 
@@ -1056,8 +1056,9 @@
                               cards->data, cards->len);
 
-  /* Unset the selection. It'll be re-set if the drag is aborted */
+  /* Unset the selection and focus. It'll be re-set if the drag is aborted */
   set_selection (board, NULL, -1, FALSE);



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]